*****************************************
:mod:`mopidy.frontends.mpd` -- MPD server
*****************************************

.. inheritance-diagram:: mopidy.frontends.mpd

.. automodule:: mopidy.frontends.mpd
    :synopsis: MPD server frontend
    :members:


MPD dispatcher
==============

.. inheritance-diagram:: mopidy.frontends.mpd.dispatcher

.. automodule:: mopidy.frontends.mpd.dispatcher
    :synopsis: MPD request dispatcher
    :members:


MPD protocol
============

.. automodule:: mopidy.frontends.mpd.protocol
    :synopsis: MPD protocol
    :members:


Audio output
------------

.. automodule:: mopidy.frontends.mpd.protocol.audio_output
    :members:


Command list
------------

.. automodule:: mopidy.frontends.mpd.protocol.command_list
    :members:


Connection
----------

.. automodule:: mopidy.frontends.mpd.protocol.connection
    :members:


Current playlist
----------------

.. automodule:: mopidy.frontends.mpd.protocol.current_playlist
    :members:

Music database
--------------

.. automodule:: mopidy.frontends.mpd.protocol.music_db
    :members:


Playback
--------

.. automodule:: mopidy.frontends.mpd.protocol.playback
    :members:


Reflection
----------

.. automodule:: mopidy.frontends.mpd.protocol.reflection
    :members:


Status
------

.. automodule:: mopidy.frontends.mpd.protocol.status
    :members:


Stickers
--------

.. automodule:: mopidy.frontends.mpd.protocol.stickers
    :members:


Stored playlists
----------------

.. automodule:: mopidy.frontends.mpd.protocol.stored_playlists
    :members:
